/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.greenseeker;

/**
 * File description enum for Greenseeker sensorfiles v/d Borne
 * This enum describes the columns in a v/d Borne greenseeker sensorfile
 *
 * @author Gerben Feenstra
 */
public enum GreenseekerFileDescriptionBorne {
    /**
     * Record ID
     */
    OBJECTID(0,1,true,java.lang.Double.class),

    /**
     * Part of GPS coordinate
     */
    LATITUDE(1,1,true,java.lang.Double.class),

    /**
     * Part of GPS coordinate
     */
    LONGITUDE(2,1,true,java.lang.Double.class),

    /**
     * Moving speed of vehicle
     */
    SPEED(3,1,true,java.lang.Double.class),

    /**
     * Direction/course
     */
    HEADING(4,1,true,java.lang.Double.class),

    /**
     * TODO: Javadoc
     */
    ELEVATION(5,1,true,java.lang.Double.class),

    /**
     * Normalized Difference Vegetation Index, calculated with values of red reflected light (VIS) and Near-infraredlight (NIR)
     * Formula = (VIS - NIR) / (VIS + NIR)
     * Measurement of fotosynthesis of a crop which can be an indication of nitrogen content, depending how large the crop is.
     * Between 0 and 1
     */
    NDVI(6,1,true,java.lang.Double.class),

    /**
     * TODO: Javadoc
     */
    VI2ND(7,1,true,java.lang.Double.class),

    /**
     * Red
     * TODO: Javadoc
     */
    RED54(8,1,true,java.lang.Double.class),

    /**
     * Near-infrared
     * TODO: Javadoc
     */
    NIR54(9,1,true,java.lang.Double.class),
    /**
     * Red
     * TODO: Javadoc
     */
    RED55(10,1,true,java.lang.Double.class),

    /**
     * Near-infrared
     * TODO: Javadoc
     */
    NIR55(11,1,true,java.lang.Double.class),

    /**
     * Red
     * TODO: Javadoc
     */
    RED57(12,1,true,java.lang.Double.class),

    /**
     * Near-infrared
     * TODO: Javadoc
     */
    NIR57(13,1,true,java.lang.Double.class),

    /**
     * Red
     * TODO: Javadoc
     */
    RED53(14,1,true,java.lang.Double.class),

    /**
     * Near-infrared
     * TODO: Javadoc
     */
    NIR53(15,1,true,java.lang.Double.class),

    /**
     * Red
     * TODO: Javadoc
     */
    RED56(16,1,true,java.lang.Double.class),

    /**
     * Near-infrared
     * TODO: Javadoc
     */
    NIR56(17,1,true,java.lang.Double.class),

    /**
     * Red
     * TODO: Javadoc
     */
    RED58(18,1,true,java.lang.Double.class),

    /**
     * Near-infrared
     * TODO: Javadoc
     */
    NIR58(19,1,true,java.lang.Double.class);

    private final int position;
    private final int mandatoryLength;
    private final boolean mandatory;
    private final static String delimiter = " ";
    private final Class theClass;

    private GreenseekerFileDescriptionBorne(int position, int mandatoryLength, boolean mandatory, Class theClass ){
            this.position = position;
            this.mandatory = mandatory;
            this.mandatoryLength = mandatoryLength;
            this.theClass = theClass;
    }

    public static String getDelimiter() {
            return delimiter;
    }

    public int getPosition() {
            return position;
    }

    public boolean isMandatory() {
            return mandatory;
    }

    public int getMandatoryLength() {
        return mandatoryLength;
    }

    public Class getTheClass() {
        return theClass;
    }
}
