/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.sensor.greenseeker;

import nl.cloudfarming.client.sensor.greenseeker.GreenseekerService;
import java.util.List;
import javax.persistence.Query;
import nl.cloudfarming.client.model.CommonModelService;
import nl.cloudfarming.client.sensor.greenseeker.GreenseekerModule;
import nl.cloudfarming.client.sensor.greenseeker.GreenseekerSensorData;

/**
 *
 * @author Gerben Feenstra
 */
public class GreenseekerServiceImpl extends CommonModelService implements GreenseekerService{

    @Override
    protected String getModuleName() {
        return GreenseekerModule.MODULE_NAME;
    }

    public void persist(List<GreenseekerSensorData> greenseekerSensorDataList){
        startTransaction();
        for (GreenseekerSensorData sensorData : greenseekerSensorDataList) {
            mergeSensorData(sensorData);
        }
        commit();
    }

    @Override
    public void persist(GreenseekerSensorData sensorData) {
        startTransaction();
        mergeGreenseekerSensorData(sensorData);
        getEntityManager().getTransaction().commit();
    }

    private void mergeGreenseekerSensorData(GreenseekerSensorData toBeMerged) {
        if (toBeMerged.getId() == 0) {
            getEntityManager().persist(toBeMerged);
        } else {
            toBeMerged = getEntityManager().merge(toBeMerged);
        }
    }

 
    public void delete(GreenseekerSensorData toBeRemoved) {
        getEntityManager().remove(toBeRemoved);
        getEntityManager().flush();
    }

     public GreenseekerSensorData findGreenseekerSensorDataById(long id){
        startTransaction();
        return getEntityManager().find(GreenseekerSensorData.class, id);
    }

     public List <GreenseekerSensorData> findAllGreenseekerSensorData(){
        startTransaction();
        Query query = this.getEntityManager().createQuery("select g from GreenseekerSensorData g");
        return query.getResultList();
    }

 
}
